﻿using System;
using System.Net;
using System.Security;
using System.IO;
using System.Linq;

namespace SharpGIS
{
	public class GZipWebClient : WebClient
	{
		[SecuritySafeCritical]
		public GZipWebClient()
		{
		}
		protected override WebRequest GetWebRequest(Uri address)
		{
			var req = base.GetWebRequest(address);
			req.Headers[HttpRequestHeader.AcceptEncoding] = "gzip"; //Set GZIP header
			return req;
		}
		protected override WebResponse GetWebResponse(WebRequest request, IAsyncResult result)
		{
			WebResponse response = null;
			try
			{
				response = base.GetWebResponse(request, result);
				if (response.Headers[HttpRequestHeader.ContentEncoding] == "gzip")
					return new GZipWebResponse(response); //If gzipped response, uncompress
				else
					return response;
			}
			catch
			{
				return null;
			}
		}
		internal class GZipWebResponse : WebResponse
		{
			WebResponse response;
			internal GZipWebResponse(WebResponse resp)
			{
				response = resp;
			}

			public override System.IO.Stream GetResponseStream()
			{
				return new SharpGIS.ZLib.GZipStream(response.GetResponseStream());
			}
			public override void Close()
			{
				response.Close();
			}
			public override long ContentLength
			{
				get { return response.ContentLength; }
			}
			public override string ContentType
			{
				get { return response.ContentType; }
			}
			public override WebHeaderCollection Headers
			{
				get { return response.Headers; }
			}
			public override Uri ResponseUri
			{
				get { return response.ResponseUri; }
			}
			public override bool SupportsHeaders
			{
				get { return response.SupportsHeaders; }
			}
		}
	}
}
